@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC;
-$Bot::Cobalt::IRC::VERSION = '0.017001';
+$Bot::Cobalt::IRC::VERSION = '0.017002';
 use v5.10;
 use strictures 2;
 
@@ -49,7 +49,8 @@ has NON_RELOADABLE => (
 has ircobjs => (
   lazy      => 1,
   is        => 'rw',
-  isa       => HashRef,
+  isa       => HashObj,
+  coerce    => 1,
   default   => sub { {} },
 );
 
